PathX extension

An extension on the Path class to provide additional utility methods.

on

Properties

subPaths → Iterable<Path>

Available on Path, provided by the PathX extension

Returns an iterable of subpaths that make up the current path.
no setter

Methods

getRandomPoint() → Offset

Available on Path, provided by the PathX extension

Returns a random point inside the path.