VectorSpoilerDrawer class

Inheritance

Constructors

VectorSpoilerDrawer()

Properties

backend ParticleRenderBackend
no setteroverride
hasContent bool
Returns true if the drawer has drawable content (e.g., particles).
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
maxParticleSize double
no setterinherited
particleColor Color
no setterinherited
particles List<Particle>
Exposes particle list if applicable (Atlas/Vector), otherwise empty.
no setterinherited
particleSpeed double
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shapePath Path?
no setterinherited

Methods

adoptStateFrom(ParticleSpoilerDrawer other) → void
inherited
buildParticleVisual(Particle particle, SpoilerContext context, {required double baseRadius}) ParticleVisual?
inherited
dispose() → void
inherited
draw(Canvas canvas, SpoilerContext context) → void
override
initializeParticles({required Iterable<Path> paths, required SpoilerConfig config}) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onParticlesInitialized() → void
override
toString() String
A string representation of this object.
inherited
update(double dt) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited