FadeConfig class

Configuration for spoiler fade behavior.

Annotations

Constructors

FadeConfig({required double padding, required double edgeThickness})
const

Properties

edgeThickness → double
Thickness of the fade edge band.
final
hashCode → int
The hash code for this object.
no setteroverride
padding → double
Padding used to expand the reveal/cover area.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override