onGetShaderUniforms property

ShaderCallback? onGetShaderUniforms
final

Optional callback to generate shader uniforms for a given rect.

This callback determines the list of float values passed to the shader for each rendered frame and particle rect. The config parameter provides access to the current configuration.

Implementation

final ShaderCallback? onGetShaderUniforms;