ParticleSpoilerDrawer class abstract
- Implemented types
- Implementers
Constructors
Properties
- backend → ParticleRenderBackend
-
no setter
- hasContent → bool
-
Returns true if the drawer has drawable content (e.g., particles).
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxParticleSize → double
-
no setter
- particleColor → Color
-
no setter
-
particles
→ List<
Particle> -
Exposes particle list if applicable (Atlas/Vector), otherwise empty.
no setteroverride
- particleSpeed → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shapePath → Path?
-
no setter
Methods
-
adoptStateFrom(
ParticleSpoilerDrawer other) → void -
buildParticleVisual(
Particle particle, SpoilerContext context, {required double baseRadius}) → ParticleVisual? -
dispose(
) → void -
override
-
draw(
Canvas canvas, SpoilerContext context) → void -
inherited
-
initializeParticles(
{required Iterable< Path> paths, required SpoilerConfig config}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onParticlesInitialized(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
double dt) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- lifeSizeMin → const double